Installation
============

Conda
-----

The ``s3fs`` library and its dependencies can be installed from the
`conda-forge <https://conda-forge.github.io/>`_ repository using
`conda <https://www.continuum.io/downloads>`_::

   $ conda install s3fs -c conda-forge

PyPI
----

You can install ``s3fs`` with pip::

    pip install s3fs

Install from source
-------------------

You can also download the ``s3fs`` library from Github and install normally::

   git clone git@github.com:fsspec/s3fs
   cd s3fs
   python setup.py install
